@@ -67,7 +67,6 @@ if ($sinfo->{'bits_per_pixel'} == 16 && $FR->{'ACCELERATED'}) {
     $F = $FR;
 }
 
-
 my $screen_width  = $sinfo->{'width'};
 my $screen_height = $sinfo->{'height'};
 
@@ -354,6 +353,7 @@ sub filled_boxes {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->box({ 'x' => int(rand($XX)), 'y' => int(rand($YY)), 'xx' => int(rand($XX)), 'yy' => int(rand($YY)), 'filled' => 1 });
         $DIRTY = 1;
+        $F->vsync();
 
     } ## end while (time < $s)
 } ## end sub filled_boxes
@@ -1330,30 +1330,35 @@ sub rotate {
 } ## end sub rotate
 
 sub flipping {
-    my $image = { %{ $IMAGES[int(rand(scalar(@IMAGES)))] } };
+    my $r = rand(scalar(@IMAGES));
+    my $image = $IMAGES[$r];
+    $image->{'image'} = "$IMAGES[$r]->{'image'}";
 
-    $image->{'y'} = $F->{'Y_CLIP'};
     my $s    = time + $factor * 2;
     my $zoom = time + $factor;
     while (time < $s) {
         foreach my $dir (qw(normal horizontal vertical both)) {
             print_it($F, "Testing Image Flip $dir");
-            my $rot = ($dir eq 'normal') ? $image : $F->blit_transform(
-                {
-                    'flip'      => $dir,
-                    'blit_data' => $image
-                }
-            );
-            $rot->{'x'} = abs(($XX - $rot->{'width'}) / 2);
-            $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
-            $F->blit_write($rot);
-            $DIRTY = 1;
-            
-            if (time < $zoom) {
-                sleep .3;
+            unless ($dir eq 'normal') {
+                my $rot = $F->blit_transform(
+                    {
+                        'flip'      => $dir,
+                        'blit_data' => $image
+                    }
+                );
+                $rot->{'image'} = "$rot->{'image'}";
+                $rot->{'x'} = abs(($XX - $rot->{'width'}) / 2);
+                $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
+                $F->blit_write($rot);
             } else {
-                sleep(1 / 30);    # Some framebuffers can't keep up
+                $r = rand(scalar(@IMAGES));
+                $image = $IMAGES[$r];
+                $image->{'image'} = "$IMAGES[$r]->{'image'}";
+                $F->blit_write($image);
             }
+            $DIRTY = 1;
+
+            sleep .3;
         } ## end foreach my $dir (qw(normal horizontal vertical both))
     } ## end while (time < $s)
 } ## end sub flipping
