@@ -41,13 +41,13 @@ $SIG{'QUIT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
     sleep 1;
-    $SIG{'QUIT'} = sub { exec('reset'); };
+    exec('reset');
 };
 $SIG{'INT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
     sleep 1;
-    $SIG{'INT'} = sub { exec('reset'); };
+    exec('reset');
 };
 
 our @pics;
@@ -74,6 +74,8 @@ foreach my $F (@f) {
         @thr,
         threads->create(
             sub {
+                local $SIG{'INT'}  = undef;
+                local $SIG{'QUIT'} = undef;
                 my $FB = shift;
                 my $p  = shift;
                 system('clear');
@@ -90,7 +92,7 @@ foreach my $F (@f) {
 while ($RUNNING) {
     sleep 1;
 }
-map { $_->cls('ON') } @f;
+# map { $_->cls('ON') } @f;
 
 foreach my $t (@thr) {
     $t->detach();
@@ -112,8 +114,8 @@ sub gather {
         } elsif (-f "$path/$file" && $file =~ /\.(jpg|jpeg|gif|tiff|bmp|png)$/i) {
             push(@pics, "$path/$file");
         }
-    } ## end foreach my $file (@dir)
-} ## end sub gather
+    }
+}
 
 sub show {
     my $FB  = shift;
