@@ -115,7 +115,6 @@ sub splash {
                 }
             }
         );
-        $self->or_mode();
         my $gfb = $self->ttf_print(
             {
                 'bounding_box' => TRUE,
@@ -205,84 +204,71 @@ sub splash {
         }
         $self->ttf_print($gfb);
     } else {
-
+        $self->normal_mode();
         # Draws the main boxes
-        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
+        $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 128, 'alpha' => 255 });
         $self->polygon(
             {
                 'coordinates' => [(400 * $hf) + $X, (80 * $vf) + $Y, (20 * $hf) + $X, (800 * $vf) + $Y, (1600 * $hf) + $X, (1078 * $vf) + $Y, (1900 * $hf) + $X, (5 * $vf) + $Y],
                 'filled'      => TRUE,
-                'gradient'    => {
-                    'start' => {
-                        'red'   => 0,
-                        'green' => 0,
-                        'blue'  => 16
-                    },
-                    'end' => {
-                        'red'   => 0,
-                        'green' => 0,
-                        'blue'  => 200
-                    }
-                }
+#                'gradient'    => {
+#                    'colors' => {
+#                        'red'   => [0,0],
+#                        'green' => [0,0],
+#                        'blue'  => [64,255],
+#                    },
+#                }
             }
         );
 
-        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 1 });
-        $self->rbox(
-            {
-                'x'      => (160 * $hf) + $X,
-                'y'      => (160 * $vf) + $Y,
-                'width'  => 1620 * $hf,
-                'height' => 780 * $vf,
-                'radius' => 15 * min($hf, $vf),
-                'filled' => TRUE
-            }
-        );
-
-        $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 0 });
+        $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 128 });
+        $self->alpha_mode();
         $self->rbox(
             {
                 'x'      => (150 * $hf) + $X,
                 'y'      => (150 * $vf) + $Y,
-                'width'  => 1620 * $hf,
-                'height' => 780 * $vf,
-                'radius' => 15 * min($hf, $vf),
+                'width'  => 1660 * $hf,
+                'height' => 800  * $vf,
+                'radius' => 15   * min($hf, $vf),
                 'filled' => TRUE
             }
         );
 
+        $self->normal_mode();
+
         ### Draws the Circle with GFB in it ###
         # The dark shadow circle
-        $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0 });
+        $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         $self->circle(
             {
                 'x'      => (207 * $hf) + $X,
                 'y'      => (207 * $vf) + $Y,
-                'radius' => 200 * min($vf, $hf),
+                'radius' => 200  * min($vf, $hf),
                 'filled' => TRUE
             }
         );
 
         # The "coin"
+        $self->set_color({ 'red' => 255, 'green' => 255, 'blue' => 255, 'alpha' => 255 });
         $self->circle(
             {
                 'x'        => (200 * $hf) + $X,
                 'y'        => (200 * $vf) + $Y,
-                'radius'   => 200 * min($hf, $vf),
+                'radius'   => 200  * min($hf, $vf),
                 'filled'   => TRUE,
                 'gradient' => {
-                    'direction' => 'horizontal',
+                    'direction' => 'vertical',
                     'colors'    => {
                         'red'   => [255, 64, 255],
-                        'green' => [255, 64, 255],
-                        'blue'  => [255, 64, 255],
+                        'green' => [255, 255, 64],
+                        'blue'  => [64, 255, 255],
                     },
                 }
             }
         );
 
         # G
-        $self->set_color({ 'red' => 32, 'green' => 32, 'blue' => 0 });
+        $self->set_color({ 'red' => 32, 'green' => 32, 'blue' => 0, 'alpha' => 255 });
         $self->filled_pie(
             {
                 'x'             => (102 * $hf) + $X,
@@ -329,17 +315,17 @@ sub splash {
         );
 
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0, 'alpha' => 255 });
         }
 
         # G
@@ -356,17 +342,17 @@ sub splash {
 
         # F
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
         }
         $self->polygon(
             {
@@ -376,19 +362,20 @@ sub splash {
             }
         );
 
+        $self->normal_mode();
         # B
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255, 'alpha' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         }
         $self->polygon(
             {
@@ -413,7 +400,7 @@ sub splash {
                 'filled' => TRUE
             }
         );
-        $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0 });
+        $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0, 'alpha' => 255 });
         $self->rbox(
             {
                 'x'      => (478 * $hf) + $X,
@@ -434,19 +421,18 @@ sub splash {
                 'filled'   => TRUE,
                 'gradient' => {
                     'start' => {
-                        'red'   => 64,
-                        'green' => 0,
-                        'blue'  => 255
+                        'red'   => 0,
+                        'green' => 255,
+                        'blue'  => 0
                     },
                     'end' => {
                         'red'   => 255,
-                        'green' => 0,
-                        'blue'  => 64
+                        'green' => 255,
+                        'blue'  => 0
                     }
                 }
             }
         );
-        $self->or_mode() if ($self->{'BITS'} == 16);
 
         if ($self->{'ACCELERATED'}) {
             $self->ttf_print(
@@ -457,7 +443,7 @@ sub splash {
                         'y'            => (351 * $vf) + $Y,
                         'height'       => 110 * $vf,
                         'wscale'       => 1.5,
-                        'color'        => '00FFFFFF',
+                        'color'        => '0101FFFF',
                         'text'         => 'Accelerated',
                         'bounding_box' => TRUE,
                         'center'       => 0,
